// ===========================================================================
//	SCAPIDrawingArea.h			1997 Spunk Cross		 All rights reserved.
// ===========================================================================

#ifndef SCAPIDRAWINGAREA_H
#define SCAPIDRAWINGAREA_H

#include "SCAPICommonIncludes.h"
#include "SCAPIWindow.h"
#include "SCAPIGroupBox.h"


// ---------------------------------------------------------------------------
//		Defines
// ---------------------------------------------------------------------------

#define SCAPIDrawingArea_default_originx		0
#define SCAPIDrawingArea_default_originy		0
#define SCAPIDrawingArea_default_width			100
#define SCAPIDrawingArea_default_height			100

#define	SCAPIDrawingArea_LeftMouseButton		0
#define	SCAPIDrawingArea_MiddleMouseButton		1
#define	SCAPIDrawingArea_RightMouseButton		2

#define	MAX_NUM_DRAWINGAREAS					100


// ---------------------------------------------------------------------------
//		SCAPIDrawingArea Class
// ---------------------------------------------------------------------------

class SCAPIDrawingArea : public CWnd
{
	friend class MFCApp;
	
	// ===========================================================
	// === Spunk Cross API, these are the routines you can use ===
	// ===========================================================
	
		// Constructor - Destructor
		// ------------------------
		
	public:
	
		SCAPIDrawingArea(	SCAPIWindow*	inWindowP,
							int				inOriginx = SCAPIDrawingArea_default_originx,
							int 			inOriginy = SCAPIDrawingArea_default_originy,
							int				inWidth = SCAPIDrawingArea_default_width,
							int				inHeight = SCAPIDrawingArea_default_height		);
		
		~SCAPIDrawingArea();
		
		
		// Member functions
		// ----------------
		
	protected:
	
		virtual void	DrawEvent();
		virtual void	LeftMouseButtonDownEvent(int	x, int	y);
		virtual void	MiddleMouseButtonDownEvent(int	x, int	y);
		virtual void	RightMouseButtonDownEvent(int	x, int	y);
		virtual void	LeftMouseButtonUpEvent(int	x, int	y);
		virtual void	MiddleMouseButtonUpEvent(int	x, int	y);
		virtual void	RightMouseButtonUpEvent(int	x, int	y);
		virtual void	MouseMove(int	x, int	y);
		virtual void	MouseEnterArea();
		virtual void	MouseLeaveArea();
		
		
	public:
	
		void	SetBackgroundColor(	float	r, 
									float	g, 
									float	b	);
									
		void	SetDrawingColor(	float	r, 
									float	g, 
									float	b	);
									
		void	Clear();
		
		void	ClearArea(	int		inOriginx,
							int 	inOriginy,
							int		inWidth,
							int		inHeight	);
							
		void	DrawPoint(	int		inPointx,
							int 	inPointy	);
							
		void	DrawLine(	int		inStartPointx,
							int 	inStartPointy,
							int		inEndPointx,
							int		inEndPointy		);
		
		void	DrawRectangle(	int		inOriginx,
								int		inOriginy,
								int		inWidth,
								int		inHeight	);
								
		void	DrawFilledRectangle(	int		inOriginx,
										int		inOriginy,
										int		inWidth,
										int		inHeight	);
										
		void	DrawOval(	int		inOriginx,
							int		inOriginy,
							int		inWidth,
							int		inHeight	);
								
		void	DrawFilledOval(	int		inOriginx,
								int		inOriginy,
								int		inWidth,
								int		inHeight	);
		
		
	// =================================
	// === Internal part, do not use ===
	// =================================					
		
		// Member variables
		// ----------------
		
	private:
		
		SCAPIGroupBox*		mBorderP;
		float				mDrawingRed;
		float				mDrawingGreen;
		float				mDrawingBlue;
		float				mBackgroundRed;
		float				mBackgroundGreen;
		float				mBackgroundBlue;
		CDC					mOffDC;
		CBitmap				mBitmap;
		int					mWidth;
		int					mHeight;
		BOOL				mMouseEntered;
		

		// Member functions
		// ----------------
		
	protected:
	
		afx_msg void		OnPaint();
		afx_msg void		OnLButtonDown(UINT, CPoint);
		afx_msg void		OnLButtonUp(UINT, CPoint);
		afx_msg void		OnMButtonDown(UINT, CPoint);
		afx_msg void		OnMButtonUp(UINT, CPoint);
		afx_msg void		OnRButtonDown(UINT, CPoint);
		afx_msg void		OnRButtonUp(UINT, CPoint);
		afx_msg void		OnMouseMove(UINT, CPoint);
		DECLARE_MESSAGE_MAP();
		
		BOOL				CursorInClient();
		
		
		// Static variables
		// ----------------
		
	private:
	
		static SCAPIDrawingArea*		sDrawingAreaList[MAX_NUM_DRAWINGAREAS];
		static int						sDrawingAreaListLength;
		
		
		// Static functions
		// ----------------
		
	private:
	
		static void		ManageEnterLeaveArea();
};

#endif